pub struct RegisterAccess {
pub ty: Option<RegisterAccessType>,
pub addr: Option<usize>,
pub len: Option<usize>,
pub before: Option<u64>,
pub after: Option<u64>,
}Expand description
Stores information of a specific registers access.
Members are all optional to allow for easy partial comparison. See the
PartialEq
implementation for more details and specific examples.
See the convenience functions access_gen::read, access_gen::read_value,
access_gen::write and access_gen::write_value for a shorthand ways to
construct RegisterAccess structs.
Fields
ty: Option<RegisterAccessType>Type of the register access.
addr: Option<usize>Address of accessed register.
len: Option<usize>Length of the access mask in bytes.
before: Option<u64>Value of the register before the access.
after: Option<u64>Value of the register after the access.
Implementations
Sourceimpl RegisterAccess
impl RegisterAccess
Sourcepub fn new(
ty: RegisterAccessType,
addr: usize,
len: usize,
before: u64,
after: u64,
) -> Self
pub fn new( ty: RegisterAccessType, addr: usize, len: usize, before: u64, after: u64, ) -> Self
Constructor for RegisterAccess that takes all its members as arguments.
See also the shorthand constructors access_gen::read, access_gen::read_value,
access_gen::write and access_gen::write_value for constructing partial
RegisterAccess structs.
Sourcepub fn seq_from_json(data: &str) -> Vec<RegisterAccess>
pub fn seq_from_json(data: &str) -> Vec<RegisterAccess>
Deserialize a sequence of register accesses from a JSON array.