pub type ReadFunction = Box<dyn FnMut(&mut RegisterMap, u64) -> u64 + Send>;Expand description
Type of read-access callback functions that can be registered in Regmock::read_fn.
Aliased Type
pub struct ReadFunction(/* private fields */);pub type ReadFunction = Box<dyn FnMut(&mut RegisterMap, u64) -> u64 + Send>;Type of read-access callback functions that can be registered in Regmock::read_fn.
pub struct ReadFunction(/* private fields */);